@@ -1,7 +1,4 @@
 """AIOHTTP-SQLAlchemy. SQLAlchemy 1.4 / 2.0 support for aiohttp."""
-import warnings
-from typing import Any, cast
-
 from aiohttp.web import Application
 from aiohttp_things import web_handlers
 from sqlalchemy.engine import Engine
@@ -14,14 +11,14 @@ from sqlalchemy.orm import Session, sessionmaker
 
 from aiohttp_sqlalchemy.constants import DEFAULT_KEY, SA_DEFAULT_KEY
 from aiohttp_sqlalchemy.decorators import sa_decorator
-from aiohttp_sqlalchemy.deprecation import _handle_deprecation
 from aiohttp_sqlalchemy.exceptions import (
     DuplicateAppKeyError,
     DuplicateRequestKeyError,
 )
 from aiohttp_sqlalchemy.middlewares import sa_middleware
-from aiohttp_sqlalchemy.typedefs import TBind, TBinds, TSessionFactory, TTarget
+from aiohttp_sqlalchemy.typedefs import TBind, TBinds, TTarget
 from aiohttp_sqlalchemy.utils import (
+    get_engine,
     get_session,
     get_session_factory,
     init_db,
@@ -30,10 +27,6 @@ from aiohttp_sqlalchemy.utils import (
     sa_session_factory,
 )
 from aiohttp_sqlalchemy.web_handlers import (
-    ItemAddMixin,
-    ItemDeleteMixin,
-    ItemEditMixin,
-    ItemViewMixin,
     ListAddMixin,
     ListDeleteMixin,
     ListEditMixin,
@@ -44,19 +37,23 @@ from aiohttp_sqlalchemy.web_handlers import (
     SAMixin,
     SAModelMixin,
     SAModelView,
+    UnitAddMixin,
+    UnitDeleteMixin,
+    UnitEditMixin,
+    UnitViewMixin,
 )
 
-__version__ = '0.31.0'
+__version__ = '0.34.0'
 
 __all__ = [
     'DEFAULT_KEY',
     'DuplicateAppKeyError',
     'DuplicateRequestKeyError',
 
-    'ItemAddMixin',
-    'ItemDeleteMixin',
-    'ItemEditMixin',
-    'ItemViewMixin',
+    'UnitAddMixin',
+    'UnitDeleteMixin',
+    'UnitEditMixin',
+    'UnitViewMixin',
 
     'ListAddMixin',
     'ListDeleteMixin',
@@ -74,12 +71,14 @@ __all__ = [
     'SAMixin',
     'SAModelView',
     'bind',
+    'get_engine',
     'get_session',
     'get_session_factory',
     'init_db',
     'sa_decorator',
     'sa_middleware',
     'setup',
+    'web_handlers',
     # Synonyms
     'DEFAULT_KEY',
     'sa_bind',
@@ -103,22 +102,18 @@ def bind(
     :param middleware: `bool` for enable middleware. True by default.
     """
     if isinstance(target, str):
-        target = cast(AsyncEngine, create_async_engine(target))
+        target = create_async_engine(target)
 
     if isinstance(target, AsyncEngine):
-        target = cast(
-            TSessionFactory,
-            sessionmaker(
-                bind=target,
-                class_=AsyncSession,
-                expire_on_commit=False,
-            ),
+        target = sessionmaker(
+            bind=target,
+            class_=AsyncSession,
+            expire_on_commit=False,
         )
 
-    for type_ in (AsyncSession, Engine, Session):
-        if isinstance(target, type_):
-            msg = f'{type_} is unsupported type of argument `target`.'
-            raise TypeError(msg)
+    if isinstance(target, (AsyncSession, Engine, Session)):
+        msg = f'{type(target)} is unsupported type of argument `target`.'
+        raise TypeError(msg)
 
     if not callable(target):
         msg = f'{target} is unsupported type of argument `target`.'
@@ -145,19 +140,3 @@ def setup(app: Application, binds: "TBinds") -> None:
 
 # Synonyms
 sa_bind = bind
-
-
-def __getattr__(name: str) -> Any:
-    if name == 'views':
-        warnings.warn(
-            '`views` module is deprecated. '
-            'Use `web_handlers` module.',
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return web_handlers
-
-    name = _handle_deprecation(name)
-    if name:
-        return globals().get(name)
-    raise AttributeError(f"module {__name__} has no attribute {name}")
