@@ -3,13 +3,13 @@ from typing import Any, List, Optional
 
 import aiohttp_things as ahth
 from aiohttp.web import View
+from aiohttp.web_urldispatcher import AbstractRoute
 from sqlalchemy import delete, select, update
 from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy.sql import Delete, Select, Update
 from sqlalchemy_things.pagination import OffsetPage, OffsetPaginator
 
 from aiohttp_sqlalchemy.constants import SA_DEFAULT_KEY
-from aiohttp_sqlalchemy.deprecation import _handle_deprecation
 from aiohttp_sqlalchemy.utils import get_session
 
 
@@ -57,17 +57,37 @@ class OffsetPaginationMixin(ahth.PaginationMixin, SelectStatementMixin):
             )
         return page
 
+    async def prepare_context(self) -> None:
+        page: Optional[OffsetPage] = await self.execute_select_stmt()
+
+        if page:
+            route: AbstractRoute = self.request.match_info.route
+
+            self.context['items'] = page.items
+
+            if page.next:
+                kw = {'page_key': page.next}
+                self.context['next_url'] = route.url_for().with_query(kw)
+            else:
+                self.context['next_url'] = page.next
+
+            if page.previous:
+                kw = {'page_key': page.previous}
+                self.context['previous_url'] = route.url_for().with_query(kw)
+            else:
+                self.context['previous_url'] = page.previous
+
 
 class PrimaryKeyMixin(ahth.PrimaryKeyMixin, SAModelMixin, metaclass=ABCMeta):
     sa_pk_attr: Any = getattr(SAModelMixin.sa_model, 'pk', None)
 
 
-class ItemAddMixin(SAModelMixin, ahth.ItemMixin, metaclass=ABCMeta):
+class UnitAddMixin(SAModelMixin, ahth.ItemMixin, metaclass=ABCMeta):
     def sa_add(self, *, key: Optional[str] = None) -> None:
         self.get_sa_session(key).add(self.item)
 
 
-class ItemDeleteMixin(
+class UnitDeleteMixin(
     DeleteStatementMixin,
     PrimaryKeyMixin,
     metaclass=ABCMeta,
@@ -78,7 +98,7 @@ class ItemDeleteMixin(
             where(self.sa_pk_attr == self.pk)
 
 
-class ItemEditMixin(
+class UnitEditMixin(
     ahth.ItemMixin,
     UpdateStatementMixin,
     PrimaryKeyMixin,
@@ -90,7 +110,7 @@ class ItemEditMixin(
             where(self.sa_pk_attr == self.pk)
 
 
-class ItemViewMixin(
+class UnitViewMixin(
     ahth.ItemMixin,
     SelectStatementMixin,
     PrimaryKeyMixin,
@@ -131,10 +151,3 @@ class SABaseView(View, SAMixin):
 
 class SAModelView(View, SAModelMixin):
     pass
-
-
-def __getattr__(name: str) -> Any:
-    name = _handle_deprecation(name)
-    if name:
-        return globals().get(name)
-    raise AttributeError(f"module {__name__} has no attribute {name}")
